@@ -10,6 +10,7 @@ import timeit
 import copy
 
 from dice_ml import diverse_counterfactuals as exp
+from dice_ml.counterfactual_explanations import CounterfactualExplanations
 
 
 class DicePyTorch(ExplainerBase):
@@ -54,7 +55,7 @@ class DicePyTorch(ExplainerBase):
                                  max_iter=5000, project_iter=0, loss_diff_thres=1e-5, loss_converge_maxiter=1, verbose=False,
                                  init_near_query_instance=True, tie_random=False, stopping_threshold=0.5,
                                  posthoc_sparsity_param=0.1, posthoc_sparsity_algorithm="linear"):
-        """Generates diverse counterfactual explanations
+        """Generates diverse counterfactual explanations.
 
         :param query_instance: Test point of interest. A dictionary of feature names and values or a single row dataframe
         :param total_CFs: Total number of counterfactuals required.
@@ -66,7 +67,7 @@ class DicePyTorch(ExplainerBase):
         :param categorical_penalty: A positive float. A weight to ensure that all levels of a categorical variable sums to 1.
         :param algorithm: Counterfactual generation algorithm. Either "DiverseCF" or "RandomInitCF".
         :param features_to_vary: Either a string "all" or a list of feature names to vary.
-        param permitted_range: Dictionary with continuous feature names as keys and permitted min-max range in list as values.
+        :param permitted_range: Dictionary with continuous feature names as keys and permitted min-max range in list as values.
                                Defaults to the range inferred from training data. If None, uses the parameters initialized in
                                data_interface.
         :param yloss_type: Metric for y-loss of the optimization function. Takes "l2_loss" or "log_loss" or "hinge_loss".
@@ -93,6 +94,7 @@ class DicePyTorch(ExplainerBase):
                                            Prefer binary search when a feature range is large
                                            (for instance, income varying from 10k to 1000k) and only if the features
                                            share a monotonic relationship with predicted outcome in the model.
+
         :return: A CounterfactualExamples object to store and visualize the resulting
                  counterfactual explanations (see diverse_counterfactuals.py).
         """
@@ -114,11 +116,11 @@ class DicePyTorch(ExplainerBase):
                 self.cont_minx.append(self.data_interface.permitted_range[feature][0])
                 self.cont_maxx.append(self.data_interface.permitted_range[feature][1])
 
-        if([total_CFs, algorithm, features_to_vary] != self.cf_init_weights):
+        if [total_CFs, algorithm, features_to_vary] != self.cf_init_weights:
             self.do_cf_initializations(total_CFs, algorithm, features_to_vary)
-        if([yloss_type, diversity_loss_type, feature_weights] != self.loss_weights):
+        if [yloss_type, diversity_loss_type, feature_weights] != self.loss_weights:
             self.do_loss_initializations(yloss_type, diversity_loss_type, feature_weights)
-        if([proximity_weight, diversity_weight, categorical_penalty] != self.hyperparameters):
+        if [proximity_weight, diversity_weight, categorical_penalty] != self.hyperparameters:
             self.update_hyperparameters(proximity_weight, diversity_weight, categorical_penalty)
 
         final_cfs_df, test_instance_df, final_cfs_df_sparse = \
@@ -127,12 +129,15 @@ class DicePyTorch(ExplainerBase):
                 project_iter, loss_diff_thres, loss_converge_maxiter, verbose, init_near_query_instance,
                 tie_random, stopping_threshold, posthoc_sparsity_param, posthoc_sparsity_algorithm)
 
-        return exp.CounterfactualExamples(data_interface=self.data_interface,
-                                          final_cfs_df=final_cfs_df,
-                                          test_instance_df=test_instance_df,
-                                          final_cfs_df_sparse=final_cfs_df_sparse,
-                                          posthoc_sparsity_param=posthoc_sparsity_param,
-                                          desired_class=desired_class)
+        counterfactual_explanations = exp.CounterfactualExamples(
+            data_interface=self.data_interface,
+            final_cfs_df=final_cfs_df,
+            test_instance_df=test_instance_df,
+            final_cfs_df_sparse=final_cfs_df_sparse,
+            posthoc_sparsity_param=posthoc_sparsity_param,
+            desired_class=desired_class)
+
+        return CounterfactualExplanations(cf_examples_list=[counterfactual_explanations])
 
     def get_model_output(self, input_instance):
         """get output probability of ML model"""
@@ -349,7 +354,7 @@ class DicePyTorch(ExplainerBase):
             for v in self.encoded_categorical_feature_indexes:
                 maxs = np.argwhere(
                     cf[v[0]:v[-1]+1] == np.amax(cf[v[0]:v[-1]+1])).flatten().tolist()
-                if(len(maxs) > 1):
+                if len(maxs) > 1:
                     if self.tie_random:
                         ix = random.choice(maxs)
                     else:
@@ -376,8 +381,8 @@ class DicePyTorch(ExplainerBase):
         """Determines the stopping condition for gradient descent."""
 
         # intermediate projections
-        if((self.project_iter > 0) & (itr > 0)):
-            if((itr % self.project_iter) == 0):
+        if self.project_iter > 0 and itr > 0:
+            if itr % self.project_iter == 0:
                 self.round_off_cfs(assign=True)
 
         # do GD for min iterations
@@ -413,7 +418,7 @@ class DicePyTorch(ExplainerBase):
                              max_iter, project_iter, loss_diff_thres, loss_converge_maxiter, verbose,
                              init_near_query_instance, tie_random, stopping_threshold, posthoc_sparsity_param,
                              posthoc_sparsity_algorithm):
-        """Finds counterfactuals by graident-descent."""
+        """Finds counterfactuals by gradient-descent."""
 
         # Prepares user defined query_instance for DiCE.
         # query_instance = self.data_interface.prepare_query_instance(query_instance=query_instance, encoding='one-hot')
