@@ -10,6 +10,7 @@ import timeit
 import copy
 
 from dice_ml import diverse_counterfactuals as exp
+from dice_ml.counterfactual_explanations import CounterfactualExplanations
 
 
 class DiceTensorFlow2(ExplainerBase):
@@ -18,6 +19,7 @@ class DiceTensorFlow2(ExplainerBase):
         """Init method
         :param data_interface: an interface class to access data related params.
         :param model_interface: an interface class to access trained ML model.
+
         """
         # initiating data related parameters
         super().__init__(data_interface)
@@ -68,7 +70,7 @@ class DiceTensorFlow2(ExplainerBase):
                                     variable sums to 1.
         :param algorithm: Counterfactual generation algorithm. Either "DiverseCF" or "RandomInitCF".
         :param features_to_vary: Either a string "all" or a list of feature names to vary.
-        param permitted_range: Dictionary with continuous feature names as keys and permitted min-max range in list as values.
+        :param permitted_range: Dictionary with continuous feature names as keys and permitted min-max range in list as values.
                                Defaults to the range inferred from training data. If None, uses the parameters initialized
                                in data_interface.
         :param yloss_type: Metric for y-loss of the optimization function. Takes "l2_loss" or "log_loss" or "hinge_loss".
@@ -99,6 +101,7 @@ class DiceTensorFlow2(ExplainerBase):
 
         :return: A CounterfactualExamples object to store and visualize the resulting counterfactual explanations
                 (see diverse_counterfactuals.py).
+
         """
         # check feature MAD validity and throw warnings
         if feature_weights == "inverse_mad":
@@ -120,9 +123,9 @@ class DiceTensorFlow2(ExplainerBase):
 
         # if([total_CFs, algorithm, features_to_vary] != self.cf_init_weights):
         self.do_cf_initializations(total_CFs, algorithm, features_to_vary)
-        if([yloss_type, diversity_loss_type, feature_weights] != self.loss_weights):
+        if [yloss_type, diversity_loss_type, feature_weights] != self.loss_weights:
             self.do_loss_initializations(yloss_type, diversity_loss_type, feature_weights)
-        if([proximity_weight, diversity_weight, categorical_penalty] != self.hyperparameters):
+        if [proximity_weight, diversity_weight, categorical_penalty] != self.hyperparameters:
             self.update_hyperparameters(proximity_weight, diversity_weight, categorical_penalty)
 
         final_cfs_df, test_instance_df, final_cfs_df_sparse = \
@@ -132,12 +135,15 @@ class DiceTensorFlow2(ExplainerBase):
                                       init_near_query_instance, tie_random, stopping_threshold,
                                       posthoc_sparsity_param, posthoc_sparsity_algorithm)
 
-        return exp.CounterfactualExamples(data_interface=self.data_interface,
-                                          final_cfs_df=final_cfs_df,
-                                          test_instance_df=test_instance_df,
-                                          final_cfs_df_sparse=final_cfs_df_sparse,
-                                          posthoc_sparsity_param=posthoc_sparsity_param,
-                                          desired_class=desired_class)
+        counterfactual_explanations = exp.CounterfactualExamples(
+            data_interface=self.data_interface,
+            final_cfs_df=final_cfs_df,
+            test_instance_df=test_instance_df,
+            final_cfs_df_sparse=final_cfs_df_sparse,
+            posthoc_sparsity_param=posthoc_sparsity_param,
+            desired_class=desired_class)
+
+        return CounterfactualExplanations(cf_examples_list=[counterfactual_explanations])
 
     def predict_fn(self, input_instance):
         """prediction function"""
@@ -352,7 +358,7 @@ class DiceTensorFlow2(ExplainerBase):
             for v in self.encoded_categorical_feature_indexes:
                 maxs = np.argwhere(
                     cf[0, v[0]:v[-1]+1] == np.amax(cf[0, v[0]:v[-1]+1])).flatten().tolist()
-                if(len(maxs) > 1):
+                if len(maxs) > 1:
                     if self.tie_random:
                         ix = random.choice(maxs)
                     else:
@@ -378,8 +384,8 @@ class DiceTensorFlow2(ExplainerBase):
         """Determines the stopping condition for gradient descent."""
 
         # intermediate projections
-        if((self.project_iter > 0) & (itr > 0)):
-            if((itr % self.project_iter) == 0):
+        if self.project_iter > 0 and itr > 0:
+            if itr % self.project_iter == 0:
                 self.round_off_cfs(assign=True)
 
         # do GD for min iterations
