@@ -5,6 +5,8 @@
 import pickle
 import numpy as np
 from dice_ml.utils.helpers import DataTransfomer
+from dice_ml.constants import ModelTypes
+from dice_ml.utils.exception import SystemException
 
 
 class BaseModel:
@@ -24,6 +26,7 @@ class BaseModel:
         :param func: function transformation required for ML model. If func is None, then func will be the identity function.
         :param kw_args: Dictionary of additional keyword arguments to pass to func. DiCE's data_interface is appended to the
                         dictionary of kw_args, by default.
+
         """
         self.model = model
         self.model_path = model_path
@@ -37,16 +40,18 @@ class BaseModel:
             with open(self.model_path, 'rb') as filehandle:
                 self.model = pickle.load(filehandle)
 
-    def get_output(self, input_instance):
-        """returns prediction probabilities for a classifier and the
-        predicted output for a regressor.
+    def get_output(self, input_instance, model_score=True):
+        """returns prediction probabilities for a classifier and the predicted output for a regressor.
 
         :returns: an array of output scores for a classifier, and a singleton
         array of predicted value for a regressor.
         """
         input_instance = self.transformer.transform(input_instance)
-        if self.model_type == "classifier":
-            return self.model.predict_proba(input_instance)
+        if model_score:
+            if self.model_type == ModelTypes.Classifier:
+                return self.model.predict_proba(input_instance)
+            else:
+                return self.model.predict(input_instance)
         else:
             return self.model.predict(input_instance)
 
@@ -58,4 +63,6 @@ class BaseModel:
         return self.get_output(temp_input).shape[1]
 
     def get_num_output_nodes2(self, input):
+        if self.model_type == ModelTypes.Regressor:
+            raise SystemException('Number of output nodes not supported for regression')
         return self.get_output(input).shape[1]
